@@ -777,7 +777,7 @@ bool Engine::loadWidgets(char *filename)
 	if (!loadData(filename))
 		return false;
 
-	char token[50], name[50], groupName[50], label[50], options[100], *line;
+	char token[50], name[50], groupName[50], label[80], options[100], *line;
 	int x, y, min, max;
 
 	int i;
@@ -935,7 +935,7 @@ void Engine::highlightWidget(int dir)
 			}
 			else
 			{
-				highlightedWidget = (Widget*)widgetList.getHead();
+				highlightedWidget = (Widget*)widgetList.getHead()->next;
 			}
 
 			if (highlightedWidget->type == 4)
@@ -1300,3 +1300,15 @@ int Engine::getValueOfFlagTokens(char *realLine)
 
 	return flags;
 }
+
+void Engine::delay(unsigned int frameLimit) {
+	unsigned int ticks = SDL_GetTicks();
+
+	if(frameLimit < ticks)
+		return;
+	
+	if(frameLimit > ticks + 16)
+		SDL_Delay(16);
+	else
+		SDL_Delay(frameLimit - ticks);
+}
