@@ -19,7 +19,6 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
 
 #include "headers.h"
-#include "SDL/SDL_endian.h"
 
 FileData::FileData()
 {
@@ -29,9 +28,17 @@ FileData::FileData()
 	location = 0;
 }
 
-void FileData::swapEndians()
+void FileData::set(char *filename, Uint32 fSize, Uint32 cSize, Uint32 location)
 {
-	cSize = SDL_SwapLE32(cSize);
-	fSize = SDL_SwapLE32(fSize);
-	location = SDL_SwapLE32(location);
+	if (strlen(filename) > 59)
+	{
+		printf("WARNING: FileData::set - FILENAME EXCEEDS 60 CHARACTERS!!!\n");
+	}
+	
+	strncpy(this->filename, filename, 59);
+	filename[59] = '\0';
+	
+	this->fSize = fSize;
+	this->cSize = cSize;
+	this->location = location;
 }
