@@ -29,6 +29,5 @@ class FileData {
 
 	FileData();
 	
-	void swapEndians();
-	void FileData::set(char *filename, Uint32 fSize, Uint32 cSize, Uint32 location);
+	void set(char *filename, Uint32 fSize, Uint32 cSize, Uint32 location);
 };
