@@ -154,6 +154,8 @@ void Graphics::updateScreen()
 			SDL_SaveBMP(screen, screenshot);
 			screenShotNumber++;
 		}
+
+		SDL_Delay(16);
 	}
 
 	if (engine->keyState[SDLK_F12])
@@ -824,11 +826,11 @@ void Graphics::setFontSize(int size)
 
 SDL_Surface *Graphics::getString(char *in, bool transparent)
 {
-	SDL_Surface *text = TTF_RenderText_Shaded(font[fontSize], in, fontForeground, fontBackground);
+	SDL_Surface *text = TTF_RenderUTF8_Shaded(font[fontSize], in, fontForeground, fontBackground);
 
 	if (!text)
 	{
-		text = TTF_RenderText_Shaded(font[fontSize], "FONT_ERROR", fontForeground, fontBackground);
+		text = TTF_RenderUTF8_Shaded(font[fontSize], "FONT_ERROR", fontForeground, fontBackground);
 	}
 
 	if (transparent)
@@ -841,11 +843,11 @@ void Graphics::drawString(char *in, int x, int y, int alignment, SDL_Surface *de
 {
 	bool center = false;
 
-	SDL_Surface *text = TTF_RenderText_Shaded(font[fontSize], in, fontForeground, fontBackground);
+	SDL_Surface *text = TTF_RenderUTF8_Shaded(font[fontSize], in, fontForeground, fontBackground);
 
 	if (!text)
 	{
-		text = TTF_RenderText_Shaded(font[fontSize], "FONT_ERROR", fontForeground, fontBackground);
+		text = TTF_RenderUTF8_Shaded(font[fontSize], "FONT_ERROR", fontForeground, fontBackground);
 	}
 
 	if (alignment == TXT_RIGHT) x -= text->w;
@@ -1041,6 +1043,7 @@ void Graphics::showLicenseErrorAndExit()
 		engine->getInput();
 		if (engine->keyState[SDLK_ESCAPE])
 			exit(1);
+		SDL_Delay(16);
 	}
 }
 
@@ -1089,6 +1092,7 @@ void Graphics::showErrorAndExit(char *error, char *param)
 		{
 			exit(1);
 		}
+		SDL_Delay(16);
 	}
 }
 
@@ -1121,5 +1125,7 @@ void Graphics::showRootWarning()
 		{
 			exit(0);
 		}
+
+		SDL_Delay(16);
 	}
 }
