@@ -8,6 +8,6 @@ class Keyboard {
 	
 		Keyboard();
 		void setDefaultKeys();
-		static char *Keyboard::translateKey(int value);
+		static char *translateKey(int value);
 
 };
