@@ -392,6 +392,8 @@ void doBosses()
 			}
 			else
 			{
+				checkObjectives(self->name, false);	
+
 				if (!self->referenced)
 				{
 					debug(("Deleting unreferenced Boss...\n"));
@@ -487,7 +489,7 @@ void checkBossBulletCollisions(Entity *bullet)
 					Math::removeBit(&bullet->flags, ENT_PUFFS);
 				}
 				
-				if (self->react != NULL)
+				if (self->react != NULL && self->health > 0)
 				{
 					self->react();
 				}
