@@ -329,8 +329,9 @@ void doAI(Entity *enemy)
 		if ((int)enemy->y > enemy->ty) enemy->dy = -1;
 	}
 
-	if (enemy->x < enemy->tx) {enemy->dx = 1; enemy->face = 0;}
-	if (enemy->x > enemy->tx) {enemy->dx = -1; enemy->face = 1;}
+	if ((int)enemy->x == enemy->tx) {enemy->dx = 0;}
+	if ((int)enemy->x < enemy->tx) {enemy->dx = 1; enemy->face = 0;}
+	if ((int)enemy->x > enemy->tx) {enemy->dx = -1; enemy->face = 1;}
 
 	if ((enemy->flags & ENT_SWIMS) && (enemy->environment == ENV_WATER))
 	{
@@ -502,7 +503,7 @@ void enemyBulletCollisions(Entity *bullet)
 				if (game.currentComboHits >= 3)
 				{
 					char message[50];
-					sprintf(message, "%d Hit Combo!", game.currentComboHits);
+					sprintf(message, _("%d Hit Combo!"), game.currentComboHits);
 					engine.setInfoMessage(message, 0, INFO_NORMAL);
 				}
 
