@@ -32,9 +32,9 @@ void newGame()
 
 void showInGameOptions()
 {
-	if (!engine.loadWidgets("data/inGameWidgets"))
+	if (!engine.loadWidgets(_("data/inGameWidgets")))
 	{
-		graphics.showErrorAndExit(ERR_FILE, "data/inGameWidgets");
+		graphics.showErrorAndExit(ERR_FILE, _("data/inGameWidgets"));
 	}
 
 	graphics.drawRect(120, 100, 400, 300, graphics.black, graphics.white, graphics.screen);
@@ -240,6 +240,8 @@ void showInGameOptions()
 			graphics.delay(500);
 			break;
 		}
+
+		SDL_Delay(16);
 	}
 }
 
@@ -295,9 +297,9 @@ int gameover()
 	audio.stopMusic();
 	audio.stopAmbiance();
 	
-	if (!engine.loadWidgets("data/gameOverWidgets"))
+	if (!engine.loadWidgets(_("data/gameOverWidgets")))
 	{
-		graphics.showErrorAndExit(ERR_FILE, "data/gameOverWidgets");
+		graphics.showErrorAndExit(ERR_FILE, _("data/gameOverWidgets"));
 	}
 
 	SDL_Surface *gameover = graphics.quickSprite("Game Over", graphics.loadImage("gfx/main/gameover.png"));
@@ -363,7 +365,7 @@ int gameover()
 		if ((cont) || (quit))
 			break;
 
-		while (SDL_GetTicks() < frameLimit){}
+		engine.delay(frameLimit);
 		frameLimit = SDL_GetTicks() + 16;
 	}
 
@@ -409,7 +411,7 @@ void showMissionInformation()
 
 	graphics.setFontSize(3);
 	graphics.setFontColor(0xff, 0xff, 0xff, 0x00, 0x00, 0x00);
-	graphics.drawString(game.stageName, 200, 20, TXT_CENTERED, panel);
+	graphics.drawString(_(game.stageName), 200, 20, TXT_CENTERED, panel);
 
 	graphics.setFontSize(0);
 
@@ -418,7 +420,7 @@ void showMissionInformation()
 	if (map.totalMIAs > 0)
 	{
 		graphics.setFontColor(0xff, 0xff, 0xff, 0x00, 0x00, 0x00);
-		sprintf(message, "%s", "Rescue %d MIAs");
+		sprintf(message, "%s", _("Rescue %d MIAs"));
 		sprintf(message, message, map.requiredMIAs);
 		graphics.drawString(message, col1, y, TXT_LEFT, panel);
 
@@ -431,7 +433,7 @@ void showMissionInformation()
 		else
 		{
 			graphics.setFontColor(0x00, 0xff, 0x00, 0x00, 0x00, 0x00);
-			graphics.drawString("Completed", col2, y, TXT_RIGHT, panel);
+			graphics.drawString(_("Completed"), col2, y, TXT_RIGHT, panel);
 		}
 	}
 
@@ -447,25 +449,25 @@ void showMissionInformation()
 		
 		if ((game.skill < 3) &&  (strstr(objective->description, "L.R.T.S.")) && (!gameData.completedWorld))
 		{
-			graphics.drawString("???? ???????? ????", col1, y, TXT_LEFT, panel);
+			graphics.drawString(_("???? ???????? ????"), col1, y, TXT_LEFT, panel);
 		}
 		else
 		{
-			graphics.drawString(objective->description, col1, y, TXT_LEFT, panel);
+			graphics.drawString(_(objective->description), col1, y, TXT_LEFT, panel);
 		}
 		
 		// this is a fake objective (for the 4th Ancient Tomb)
 		if (objective->targetValue == -1)
 		{
 			graphics.setFontColor(0xff, 0x00, 0x00, 0x00, 0x00, 0x00);
-			graphics.drawString("Incomplete", col2, y, TXT_RIGHT, panel);
+			graphics.drawString(_("Incomplete"), col2, y, TXT_RIGHT, panel);
 		}
 		else if (objective->currentValue < objective->targetValue)
 		{
 			graphics.setFontColor(0xff, 0x00, 0x00, 0x00, 0x00, 0x00);
 			if (objective->targetValue == 1)
 			{
-				graphics.drawString("Incomplete", col2, y, TXT_RIGHT, panel);
+				graphics.drawString(_("Incomplete"), col2, y, TXT_RIGHT, panel);
 			}
 			else
 			{
@@ -476,19 +478,19 @@ void showMissionInformation()
 		else
 		{
 			graphics.setFontColor(0x00, 0xff, 0x00, 0x00, 0x00, 0x00);
-			graphics.drawString("Completed", col2, y, TXT_RIGHT, panel);
+			graphics.drawString(_("Completed"), col2, y, TXT_RIGHT, panel);
 		}
 	}
 	
 	if (game.skill == 3)
 	{
 		graphics.setFontColor(0xff, 0xff, 0x00, 0x00, 0x00, 0x00);
-		sprintf(message, "Time Limit - %d:%.2d Minutes", map.remainingMinutes, map.remainingSeconds);
+		sprintf(message, _("Time Limit - %d:%.2d Minutes"), map.remainingMinutes, map.remainingSeconds);
 		graphics.drawString(message, 200, 260, TXT_CENTERED, panel);
 	}
 	
 	graphics.setFontColor(0xff, 0xff, 0xff, 0x00, 0x00, 0x00);
-	graphics.drawString("Press Fire to Continue", 200, 280, TXT_CENTERED, panel);
+	graphics.drawString(_("Press Fire to Continue"), 200, 280, TXT_CENTERED, panel);
 
 	engine.flushInput();
 	engine.clearInput();
@@ -520,7 +522,7 @@ void showMissionInformation()
 		graphics.blit(panelBack, 320, 220, graphics.screen, true);
 		graphics.blit(panel, 320, 220, graphics.screen, true);
 
-		while (SDL_GetTicks() < frameLimit){}
+		engine.delay(frameLimit);
 		frameLimit = SDL_GetTicks() + 16;
 
 		if (engine.userAccepts())
@@ -548,7 +550,7 @@ void beamInPlayer()
 	
 	while (beamInTime > 0)
 	{
-		while (SDL_GetTicks() < frameLimit){}
+		engine.delay(frameLimit);
 		frameLimit = SDL_GetTicks() + 16;
 		
 		doGameStuff();
@@ -567,6 +569,7 @@ void beamInPlayer()
 	player.immune = 120;
 	player.environment = ENV_AIR;
 	player.oxygen = 7;
+	player.fuel = 7;
 	Math::removeBit(&player.flags, ENT_FLIES);
 }
 
@@ -796,6 +799,8 @@ int doGame()
 			{
 				audio.resume();
 			}
+
+			SDL_Delay(16);
 		}
 		
 		if ((engine.keyState[SDLK_F3]) && (engine.cheatSkipLevel))
@@ -811,7 +816,7 @@ int doGame()
 		}		
 		#endif
 		
-		while (SDL_GetTicks() < (frameLimit)){}
+		engine.delay(frameLimit);
 		frameLimit = SDL_GetTicks()  + 16;
 		
 		if (game.missionOverReason == MIS_GAMECOMPLETE)
