@@ -56,7 +56,7 @@ void doStatusBar()
 
 	graphics.blit(graphics.infoBar, 0, 0, graphics.screen, false);
 
-	graphics.drawString("Health", 50, 5, TXT_RIGHT, graphics.screen);
+	graphics.drawString(_("Health"), 50, 5, TXT_RIGHT, graphics.screen);
 
 	for (int i = 0 ; i < MAX_HEALTH ; i++)
 	{
@@ -73,7 +73,7 @@ void doStatusBar()
 
 	if ((!game.hasAquaLung) && (!engine.cheatExtras))
 	{
-		graphics.drawString("Oxygen", 305, 5, TXT_RIGHT, graphics.screen);
+		graphics.drawString(_("Oxygen"), 305, 5, TXT_RIGHT, graphics.screen);
 
 		for (int i = 0 ; i < 7 ; i++)
 		{
@@ -90,7 +90,7 @@ void doStatusBar()
 	}
 	else if ((game.hasJetPack) || (engine.cheatExtras))
 	{
-		graphics.drawString("Jetpack", 260, 5, false, graphics.screen);
+		graphics.drawString(_("Jetpack"), 305, 5, TXT_RIGHT, graphics.screen);
 
 		for (int i = 0 ; i < 7 ; i++)
 		{
@@ -130,7 +130,7 @@ void doStatusBar()
 			}
 	
 			graphics.blit(graphics.infoBar, 0, 455, graphics.screen, false);
-			graphics.drawString(engine.message, 320, 466, true, graphics.screen);
+			graphics.drawString(_(engine.message), 320, 466, true, graphics.screen);
 			
 			engine.messageTime--;
 			if (engine.messageTime == -1)
@@ -148,7 +148,7 @@ void doStatusBar()
 		{
 			graphics.blit(graphics.infoBar, 0, 455, graphics.screen, false);
 			
-			graphics.drawString(map.mainBossPart->name, 255, 460, TXT_RIGHT, graphics.screen);
+			graphics.drawString(_(map.mainBossPart->name), 255, 460, TXT_RIGHT, graphics.screen);
 			graphics.drawRect(265 - 1, 463 - 1, 200 + 2, 10 + 2, graphics.white, graphics.screen);
 			graphics.drawRect(265, 463, 200, 10, graphics.black, graphics.screen);
 			
@@ -159,12 +159,12 @@ void doStatusBar()
 		}
 	}
 
-	sprintf(string, "%s %s", "Weapon:", player.currentWeapon->name);
+	sprintf(string, "%s %s", _("Weapon:"), _(player.currentWeapon->name));
 	graphics.drawString(string, 630, 5, TXT_RIGHT, graphics.screen);
 	
 	if (game.skill == 3)
 	{
-		sprintf(string, "Time Remaining: %.2d:%.2d", map.remainingMinutes, map.remainingSeconds);
+		sprintf(string, _("Time Remaining: %.2d:%.2d"), map.remainingMinutes, map.remainingSeconds);
 		graphics.blit(graphics.infoBar, 0, 25, graphics.screen, false);
 		
 		if ((map.remainingMinutes > 0) || (map.remainingSeconds > 0))
@@ -189,7 +189,7 @@ void doStatusBar()
 		{
 			graphics.setFontColor(0xff, 0x00, 0x00, 0x00, 0x00, 0x00);
 			graphics.setFontSize(3);
-			graphics.drawString("Mission Failed! Time Up!", 320, 220, TXT_CENTERED, graphics.screen);
+			graphics.drawString(_("Mission Failed! Time Up!"), 320, 220, TXT_CENTERED, graphics.screen);
 			graphics.setFontSize(0);
 			game.canContinue = 0;
 		}
@@ -212,30 +212,30 @@ void doPauseInfo()
 	graphics.setFontColor(0xff, 0xff, 0xff, 0x00, 0x00, 0x00);
 
 	//#if !USEPAK
-	sprintf(string, "Position = %d:%d", (int)player.x, (int)player.y);
+	sprintf(string, _("Position = %d:%d"), (int)player.x, (int)player.y);
 	graphics.drawString(string, 5, 25, false, graphics.screen);
 	//#endif
 
-	graphics.drawString("*** PAUSED ***", 320, y, TXT_CENTERED, graphics.screen);
+	graphics.drawString(_("*** PAUSED ***"), 320, y, TXT_CENTERED, graphics.screen);
 
-	graphics.drawString("MIAs in Area", col1, y += 30, TXT_RIGHT, graphics.screen);
+	graphics.drawString(_("MIAs in Area"), col1, y += 30, TXT_RIGHT, graphics.screen);
 	sprintf(string, "%d", map.totalMIAs - map.foundMIAs);
 	graphics.drawString(string, col2, y, TXT_LEFT, graphics.screen);
 
-	graphics.drawString("Enemies Defeated", col1, y += 20, TXT_RIGHT, graphics.screen);
+	graphics.drawString(_("Enemies Defeated"), col1, y += 20, TXT_RIGHT, graphics.screen);
 	sprintf(string, "%d", game.currentMissionEnemiesDefeated);
 	graphics.drawString(string, col2, y, TXT_LEFT, graphics.screen);
 
-	graphics.drawString("Items Collected", col1, y += 20, TXT_RIGHT, graphics.screen);
+	graphics.drawString(_("Items Collected"), col1, y += 20, TXT_RIGHT, graphics.screen);
 	sprintf(string, "%d / %d", map.foundItems, map.totalItems);
 	graphics.drawString(string, col2, y, TXT_LEFT, graphics.screen);
 
-	graphics.drawString("Best Combo", col1, y += 20, TXT_RIGHT, graphics.screen);
-	sprintf(string, "%s", "%d Hits");
+	graphics.drawString(_("Best Combo"), col1, y += 20, TXT_RIGHT, graphics.screen);
+	sprintf(string, "%s", _("%d Hits"));
 	sprintf(string, string, game.maxComboHits);
 	graphics.drawString(string, col2, y, TXT_LEFT, graphics.screen);
 
-	graphics.drawString("++ Inventory ++", 320, y += 40, TXT_CENTERED, graphics.screen);
+	graphics.drawString(_("++ Inventory ++"), 320, y += 40, TXT_CENTERED, graphics.screen);
 	showCarriedItems();
 
 	// Do the objectives list
@@ -247,7 +247,7 @@ void doPauseInfo()
 	if (map.totalMIAs > 0)
 	{
 		graphics.setFontColor(0xff, 0xff, 0xff, 0x00, 0x00, 0x00);
-		sprintf(message, "%s", "Rescue %d MIAs");
+		sprintf(message, "%s", _("Rescue %d MIAs"));
 		sprintf(message, message, map.requiredMIAs);
 		graphics.drawString(message, col1, y, TXT_RIGHT, graphics.screen);
 
@@ -260,7 +260,7 @@ void doPauseInfo()
 		else
 		{
 			graphics.setFontColor(0x00, 0xff, 0x00, 0x00, 0x00, 0x00);
-			graphics.drawString("Completed", col2, y, TXT_LEFT, graphics.screen);
+			graphics.drawString(_("Completed"), col2, y, TXT_LEFT, graphics.screen);
 		}
 	}
 
@@ -274,25 +274,25 @@ void doPauseInfo()
 		
 		if ((game.skill < 3) &&  (strstr(objective->description, "L.R.T.S.")) && (!gameData.completedWorld))
 		{
-			graphics.drawString("???? ???????? ????", col1, y, TXT_RIGHT, graphics.screen);
+			graphics.drawString(_("???? ???????? ????"), col1, y, TXT_RIGHT, graphics.screen);
 		}
 		else
 		{
-			graphics.drawString(objective->description, col1, y, TXT_RIGHT, graphics.screen);
+			graphics.drawString(_(objective->description), col1, y, TXT_RIGHT, graphics.screen);
 		}
 		
 		// this is a fake objective (for the 4th Ancient Tomb)
 		if (objective->targetValue == -1)
 		{
 			graphics.setFontColor(0xff, 0x00, 0x00, 0x00, 0x00, 0x00);
-			graphics.drawString("Incomplete", col2, y, TXT_LEFT, graphics.screen);
+			graphics.drawString(_("Incomplete"), col2, y, TXT_LEFT, graphics.screen);
 		}
 		else if (objective->currentValue < objective->targetValue)
 		{
 			graphics.setFontColor(0xff, 0x00, 0x00, 0x00, 0x00, 0x00);
 			if (objective->targetValue == 1)
 			{
-				graphics.drawString("Incomplete", col2, y, TXT_LEFT, graphics.screen);
+				graphics.drawString(_("Incomplete"), col2, y, TXT_LEFT, graphics.screen);
 			}
 			else
 			{
@@ -303,13 +303,13 @@ void doPauseInfo()
 			if (!objective->required)
 			{
 				graphics.setFontColor(0xff, 0xff, 0xff, 0x00, 0x00, 0x00);
-				graphics.drawString("(optional)", 450, y, TXT_LEFT, graphics.screen);
+				graphics.drawString(_("(optional)"), 450, y, TXT_LEFT, graphics.screen);
 			}
 		}
 		else
 		{
 			graphics.setFontColor(0x00, 0xff, 0x00, 0x00, 0x00, 0x00);
-			graphics.drawString("Completed", col2, y, TXT_LEFT, graphics.screen);
+			graphics.drawString(_("Completed"), col2, y, TXT_LEFT, graphics.screen);
 		}
 	}
 
@@ -317,6 +317,6 @@ void doPauseInfo()
 
 	y += 10;
 
-	sprintf(string, "%s - %.2d:%.2d:%.2d", "Mission Time", game.currentMissionHours, game.currentMissionMinutes, game.currentMissionSeconds);
+	sprintf(string, "%s - %.2d:%.2d:%.2d", _("Mission Time"), game.currentMissionHours, game.currentMissionMinutes, game.currentMissionSeconds);
 	graphics.drawString(string, 320, 430, TXT_CENTERED, graphics.screen);
 }
