@@ -22,7 +22,7 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 void checkForLicense()
 {
-	if (!engine.loadData("data/LICENSE"))
+	if (!engine.loadData(_("data/LICENSE")))
 	{
 		graphics.showLicenseErrorAndExit();
 	}
@@ -70,7 +70,7 @@ void showLicense()
 
 	graphics.delay(4000);
 
-	graphics.drawString("Press Space to Continue...", 320, 440, true, graphics.screen);
+	graphics.drawString(_("Press Space to Continue..."), 320, 440, true, graphics.screen);
 
 	engine.flushInput();
 	engine.clearInput();
@@ -81,6 +81,7 @@ void showLicense()
 		engine.getInput();
 		if (engine.keyState[SDLK_SPACE])
 			break;
+		SDL_Delay(16);
 	}
 	
 	SDL_FillRect(graphics.screen, NULL, graphics.black);
