@@ -42,19 +42,19 @@ void initSaveSlots()
 
 		if (!fp)
 		{
-			strcpy(string, "%.2d - Empty");
-			sprintf(engine.saveSlot[i], string, (i + 1));
+			strcpy(string, "%.2d - %s");
+			sprintf(engine.saveSlot[i], string, (i + 1), _("Empty"));
 		}
 		else
 		{
 			if (fread(&tempGame, sizeof(Game), 1, fp) != 1)
 			{
-				strcpy(string, "%.2d - Corrupt Save Data");
-				sprintf(engine.saveSlot[i], string, (i + 1));
+				strcpy(string, "%.2d - %s");
+				sprintf(engine.saveSlot[i], string, (i + 1), _("Corrupt Save Data"));
 			}
 			else
 			{
-				sprintf(engine.saveSlot[i], "%.2d - %s (%.2d:%.2d:%.2d)", (i + 1), tempGame.stageName, tempGame.totalHours, tempGame.totalMinutes, tempGame.totalSeconds);
+				sprintf(engine.saveSlot[i], "%.2d - %s (%.2d:%.2d:%.2d)", (i + 1), _(tempGame.stageName), tempGame.totalHours, tempGame.totalMinutes, tempGame.totalSeconds);
 			}
 
 			if (stat(filename, &fileInfo) != -1)
@@ -302,6 +302,8 @@ int confirmSave()
 		{
 			break;
 		}
+
+		SDL_Delay(16);
 	}
 	
 	SDL_FillRect(graphics.screen, NULL, graphics.black);
@@ -325,7 +327,7 @@ void saveGame()
 		return;
 
 	graphics.setFontSize(1);
-	sprintf(message, "Saving Game to Save Slot #%d. Please Wait...", slot + 1);
+	sprintf(message, _("Saving Game to Save Slot #%d. Please Wait..."), slot + 1);
 	graphics.drawString(message, 320, 220, true, graphics.screen);
 	graphics.updateScreen();
 
@@ -401,7 +403,7 @@ void saveGame()
 	
 	SDL_Delay(500);
 
-	graphics.drawString("Save Complete", 320, 260, true, graphics.screen);
+	graphics.drawString(_("Save Complete"), 320, 260, true, graphics.screen);
 	graphics.updateScreen();
 
 	SDL_Delay(500);
