@@ -20,6 +20,8 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 #include "main.h"
 
+#include <locale.h>
+
 void showHelp()
 {
 	printf("\n");
@@ -55,6 +57,10 @@ int main(int argc, char *argv[])
 	debug(("Not Using PAK...\n"));
 	#endif
 
+	bindtextdomain("blobwars", LOCALEDIR);
+	setlocale(LC_ALL, "");
+	textdomain("blobwars");
+
 	atexit(cleanup);
 
 	int requiredSection = SECTION_INTRO;
