@@ -141,6 +141,8 @@ void addBlips(List *blipList, int mapX, int mapY, int type)
 			blipType = graphics.getSprite("EnemyArrow", true);
 			ent = (Entity*)map.enemyList.getHead();
 			break;
+		default:
+			return;
 	}
 
 	RadarBlip *blip;
@@ -377,23 +379,23 @@ void showMap(int centerX, int centerY)
 
 	graphics.setFontColor(0xff, 0xff, 0xff, 0x00, 0x00, 0x00);
 	graphics.setFontSize(3);
-	graphics.drawString(game.stageName, 320, 30, TXT_CENTERED, graphics.screen);
+	graphics.drawString(_(game.stageName), 320, 30, TXT_CENTERED, graphics.screen);
 
 	graphics.setFontSize(0);
 	
 	graphics.drawRect(160, 414, 7, 7, graphics.yellow, graphics.white, graphics.screen);
-	graphics.drawString("MIAs", 175, 410, TXT_LEFT, graphics.screen);
+	graphics.drawString(_("MIAs"), 175, 410, TXT_LEFT, graphics.screen);
 
 	graphics.drawRect(290, 414, 7, 7, graphics.blue, graphics.white, graphics.screen);
-	graphics.drawString("Items", 320, 417, TXT_CENTERED, graphics.screen);
+	graphics.drawString(_("Items"), 305, 410, TXT_LEFT, graphics.screen);
 
 	graphics.drawRect(415, 414, 7, 7, graphics.red, graphics.white, graphics.screen);
-	graphics.drawString("Enemies", 480, 410, TXT_RIGHT, graphics.screen);
+	graphics.drawString(_("Enemies"), 430, 410, TXT_LEFT, graphics.screen);
 
 	graphics.setFontSize(1);
-	sprintf(string, "%s - %.2d:%.2d:%.2d", "Mission Time", game.currentMissionHours, game.currentMissionMinutes, game.currentMissionSeconds);
+	sprintf(string, "%s - %.2d:%.2d:%.2d", _("Mission Time"), game.currentMissionHours, game.currentMissionMinutes, game.currentMissionSeconds);
 	graphics.drawString(string, 320, 60, TXT_CENTERED, graphics.screen);
-	graphics.drawString("Press Button to Continue...", 320, 450, TXT_CENTERED, graphics.screen);
+	graphics.drawString(_("Press Button to Continue..."), 320, 450, TXT_CENTERED, graphics.screen);
 
 	engine.flushInput();
 	engine.clearInput();
@@ -434,6 +436,8 @@ void showMap(int centerX, int centerY)
 					break;
 			}
 		}
+
+		SDL_Delay(16);
 	}
 
 	blipList.clear();
@@ -448,6 +452,38 @@ void showMap(int centerX, int centerY)
 
 void evaluateMapAttribute(Entity *ent, int mapAttribute)
 {
+	switch (mapAttribute)
+	{
+		case MAP_AIR_WALL_1:
+		case MAP_AIR_WALL_2:
+		case MAP_AIR_WALL_3:
+		case MAP_AIR_CEILING_1:
+			mapAttribute = MAP_AIR;
+			break;
+		case MAP_AIR_WALL_4:
+			if (map.isCavesTileset)
+			{
+				mapAttribute = MAP_AIR;
+			}
+			break;
+		case MAP_AIR_CEILING_2:
+			if (map.isGrasslandsTileset)
+			{
+				mapAttribute = MAP_AIR;
+			}
+			else if (map.isCavesTileset)
+			{
+				mapAttribute = MAP_WATER;
+			}
+			break;
+		case MAP_WATER_WALL:
+			if (map.isCavesTileset)
+			{
+				mapAttribute = MAP_WATER;
+			}
+			break;
+	}
+
 	switch (mapAttribute)
 	{
 		case MAP_AIR:
