@@ -20,6 +20,8 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 #include "headers.h"
 
+extern void addTeleportParticles(float x, float y, int amount, int soundToPlay);
+extern void activateTrigger(char *linkName, char *activateMessage, bool active);
 extern void moveEntity(Entity *ent);
 
 extern Audio audio;
