@@ -29,6 +29,7 @@ void resetPlayer()
 	player.immune = 120;
 	player.environment = ENV_AIR;
 	player.oxygen = 7;
+	player.fuel = 7;
 	addTeleportParticles(player.x + 10, player.y + 10, 50, SND_TELEPORT2);
 	
 	Math::removeBit(&player.flags, ENT_FLIES);
@@ -364,6 +365,30 @@ void doPlayer()
 
 	moveEntity(&player);
 
+	// Math::limitFloat(&player.x, 10, map.limitRight + 608);
+	// moveEntity() limits x < 10
+	if (player.x > map.limitRight + 608)
+	{
+		player.x = map.limitRight + 608;
+		if (player.dx > 0)
+		{
+			player.dx = 0;
+		}
+	}
+	// Math::limitFloat(&player.y, map.limitUp + 5, (MAPHEIGHT * BRICKSIZE) + 64);
+	if (player.y < map.limitUp + 5)
+	{
+		player.y = map.limitUp + 5;
+		if (player.dy < 0)
+		{
+			player.dy = 0;
+		}
+	}
+	else if (player.y > (MAPHEIGHT * BRICKSIZE) + 64)
+	{
+		player.y = (MAPHEIGHT * BRICKSIZE) + 64;
+	}
+
 	if (engine.isKey(KEY_FIRE))
 	{
 		if (player.reload == 0)
