@@ -191,7 +191,19 @@ void doSpawnPoints()
 							y = y >> BRICKSHIFT;
 							if (map.isSolid(x, y))
 							{
-								map.data[x][y] = MAP_AIR;
+								int waterLevel = (int)map.waterLevel;
+								if (waterLevel == -1 || y < waterLevel)
+								{
+									map.data[x][y] = MAP_AIR;
+								}
+								else if (y == waterLevel)
+								{
+									map.data[x][y] = MAP_WATERANIM;
+								}
+								else
+								{
+									map.data[x][y] = MAP_WATER;
+								}
 							}
 							break;
 						case HAZARD_POWERBULLETS:
