@@ -118,7 +118,7 @@ void setupSaveWidgets()
 		sprintf(widgetName, "save%d", i + 1);
 		strcpy(engine.getWidgetByName(widgetName)->label, engine.saveSlot[i]);
 		
-		if ((strstr(engine.saveSlot[i], "Empty")) || (strstr(engine.saveSlot[i], "Corrupt")))
+		if ((strstr(engine.saveSlot[i], _("Empty"))) || (strstr(engine.saveSlot[i], _("Corrupt"))))
 		{
 			engine.enableWidget(widgetName, false);
 		}
@@ -133,9 +133,9 @@ void setupSaveWidgets()
 */
 void loadTitleWidgets()
 {
-	if (!engine.loadWidgets("data/titleWidgets"))
+	if (!engine.loadWidgets(_("data/titleWidgets")))
 	{
-		graphics.showErrorAndExit(ERR_FILE, "data/titleWidgets");
+		graphics.showErrorAndExit(ERR_FILE, _("data/titleWidgets"));
 	}
 
 	initSaveSlots();
@@ -180,17 +180,19 @@ int title()
 	graphics.setFontColor(0xff, 0xff, 0xff, 0x00, 0x00, 0x00);
 
 	graphics.setFontSize(3);
-	SDL_Surface *presents = graphics.quickSprite("Presents", graphics.getString("Presents", true));
-	SDL_Surface *sdl = graphics.quickSprite("SDL", graphics.getString("An SDL Game", true));
+	SDL_Surface *presents = graphics.quickSprite("Presents", graphics.getString(_("Presents"), true));
+	SDL_Surface *sdl = graphics.quickSprite("SDL", graphics.getString(_("An SDL Game"), true));
 
 	graphics.setFontSize(2);
-	SDL_Surface *subTitle = graphics.quickSprite("SubTitle", graphics.getString("Blob Wars : Episode I", true));
+	SDL_Surface *subTitle = graphics.quickSprite("SubTitle", graphics.getString(_("Blob Wars : Episode I"), true));
 
 	graphics.setFontSize(0);
-	SDL_Surface *copyright = graphics.quickSprite("Copyright", graphics.getString("Copyright (C) 2004, 2005 Parallel Realities", true));
+	SDL_Surface *copyright = graphics.quickSprite("Copyright", graphics.getString(_("Copyright (C) 2004, 2005 Parallel Realities"), true));
 
 	char v[50];
-	sprintf(v, "Version %.2f", VERSION);
+	#define STRINGIFY_VALUE(x) STRINGIFY(x)
+	#define STRINGIFY(x) #x
+	sprintf(v, _("Version %s"), STRINGIFY_VALUE(VERSION));
 	SDL_Surface *version = graphics.quickSprite("Version", graphics.getString(v, true));
 
 	SDL_SetAlpha(title, SDL_SRCALPHA|SDL_RLEACCEL, 0);
@@ -401,7 +403,7 @@ int title()
 			break;
 		}
 
-		while (SDL_GetTicks() < (frameLimit)){}
+		engine.delay(frameLimit);
 		frameLimit = SDL_GetTicks()  + 16;
 	}
 
@@ -430,8 +432,7 @@ int title()
 		
 		debug(("Map Name = %s", game.mapName))
 	}
-		
-	if (engine.skill == -1)
+	else if (engine.skill == -1)
 	{
 		game.setMapName("data/practice");
 		game.setStageName("Training Mission");
@@ -439,8 +440,7 @@ int title()
 		game.skill = 1;
 		return SECTION_GAME;
 	}
-	
-	if (engine.skill == 3)
+	else if (engine.skill == 3)
 	{
 		game.skill = 3;
 		game.hasAquaLung = game.hasJetPack = true;
@@ -472,7 +472,7 @@ void doCredits()
 
 	SDL_Surface *backdrop = graphics.quickSprite("CreditsBackGround", graphics.loadImage("gfx/main/creditsBack.png"));
 
-	engine.loadData("data/credits");
+	engine.loadData(_("data/credits"));
 
 	line = strtok((char*)engine.dataBuffer, "\n");
 
@@ -545,6 +545,8 @@ void doCredits()
 			graphics.drawRect(0, 450, 640, 30, graphics.black, graphics.screen);
 			graphics.drawRect(0, 0, 640, 30, graphics.black, graphics.screen);
 		}
+
+		SDL_Delay(16);
 	}
 
 	graphics.delay(12000);
